/**
 * File navigation.js.
 *
 * Handles toggling the navigation menu for small screens and enables TAB key
 * navigation support for dropdown menus.
 */
( function() {
    var gridwp_secondary_container, gridwp_secondary_button, gridwp_secondary_menu, gridwp_secondary_links, gridwp_secondary_i, gridwp_secondary_len;

    gridwp_secondary_container = document.getElementById( 'gridwp-secondary-navigation' );
    if ( ! gridwp_secondary_container ) {
        return;
    }

    gridwp_secondary_button = gridwp_secondary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof gridwp_secondary_button ) {
        return;
    }

    gridwp_secondary_menu = gridwp_secondary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof gridwp_secondary_menu ) {
        gridwp_secondary_button.style.display = 'none';
        return;
    }

    gridwp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === gridwp_secondary_menu.className.indexOf( 'nav-menu' ) ) {
        gridwp_secondary_menu.className += ' nav-menu';
    }

    gridwp_secondary_button.onclick = function() {
        if ( -1 !== gridwp_secondary_container.className.indexOf( 'gridwp-toggled' ) ) {
            gridwp_secondary_container.className = gridwp_secondary_container.className.replace( ' gridwp-toggled', '' );
            gridwp_secondary_button.setAttribute( 'aria-expanded', 'false' );
            gridwp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            gridwp_secondary_container.className += ' gridwp-toggled';
            gridwp_secondary_button.setAttribute( 'aria-expanded', 'true' );
            gridwp_secondary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    gridwp_secondary_links    = gridwp_secondary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( gridwp_secondary_i = 0, gridwp_secondary_len = gridwp_secondary_links.length; gridwp_secondary_i < gridwp_secondary_len; gridwp_secondary_i++ ) {
        gridwp_secondary_links[gridwp_secondary_i].addEventListener( 'focus', gridwp_secondary_toggleFocus, true );
        gridwp_secondary_links[gridwp_secondary_i].addEventListener( 'blur', gridwp_secondary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function gridwp_secondary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'gridwp-focus' ) ) {
                    self.className = self.className.replace( ' gridwp-focus', '' );
                } else {
                    self.className += ' gridwp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( gridwp_secondary_container ) {
        var touchStartFn, gridwp_secondary_i,
            parentLink = gridwp_secondary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, gridwp_secondary_i;

                if ( ! menuItem.classList.contains( 'gridwp-focus' ) ) {
                    e.preventDefault();
                    for ( gridwp_secondary_i = 0; gridwp_secondary_i < menuItem.parentNode.children.length; ++gridwp_secondary_i ) {
                        if ( menuItem === menuItem.parentNode.children[gridwp_secondary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[gridwp_secondary_i].classList.remove( 'gridwp-focus' );
                    }
                    menuItem.classList.add( 'gridwp-focus' );
                } else {
                    menuItem.classList.remove( 'gridwp-focus' );
                }
            };

            for ( gridwp_secondary_i = 0; gridwp_secondary_i < parentLink.length; ++gridwp_secondary_i ) {
                parentLink[gridwp_secondary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( gridwp_secondary_container ) );
} )();


( function() {
    var gridwp_primary_container, gridwp_primary_button, gridwp_primary_menu, gridwp_primary_links, gridwp_primary_i, gridwp_primary_len;

    gridwp_primary_container = document.getElementById( 'gridwp-primary-navigation' );
    if ( ! gridwp_primary_container ) {
        return;
    }

    gridwp_primary_button = gridwp_primary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof gridwp_primary_button ) {
        return;
    }

    gridwp_primary_menu = gridwp_primary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof gridwp_primary_menu ) {
        gridwp_primary_button.style.display = 'none';
        return;
    }

    gridwp_primary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === gridwp_primary_menu.className.indexOf( 'nav-menu' ) ) {
        gridwp_primary_menu.className += ' nav-menu';
    }

    gridwp_primary_button.onclick = function() {
        if ( -1 !== gridwp_primary_container.className.indexOf( 'gridwp-toggled' ) ) {
            gridwp_primary_container.className = gridwp_primary_container.className.replace( ' gridwp-toggled', '' );
            gridwp_primary_button.setAttribute( 'aria-expanded', 'false' );
            gridwp_primary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            gridwp_primary_container.className += ' gridwp-toggled';
            gridwp_primary_button.setAttribute( 'aria-expanded', 'true' );
            gridwp_primary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    gridwp_primary_links    = gridwp_primary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( gridwp_primary_i = 0, gridwp_primary_len = gridwp_primary_links.length; gridwp_primary_i < gridwp_primary_len; gridwp_primary_i++ ) {
        gridwp_primary_links[gridwp_primary_i].addEventListener( 'focus', gridwp_primary_toggleFocus, true );
        gridwp_primary_links[gridwp_primary_i].addEventListener( 'blur', gridwp_primary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function gridwp_primary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'gridwp-focus' ) ) {
                    self.className = self.className.replace( ' gridwp-focus', '' );
                } else {
                    self.className += ' gridwp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( gridwp_primary_container ) {
        var touchStartFn, gridwp_primary_i,
            parentLink = gridwp_primary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, gridwp_primary_i;

                if ( ! menuItem.classList.contains( 'gridwp-focus' ) ) {
                    e.preventDefault();
                    for ( gridwp_primary_i = 0; gridwp_primary_i < menuItem.parentNode.children.length; ++gridwp_primary_i ) {
                        if ( menuItem === menuItem.parentNode.children[gridwp_primary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[gridwp_primary_i].classList.remove( 'gridwp-focus' );
                    }
                    menuItem.classList.add( 'gridwp-focus' );
                } else {
                    menuItem.classList.remove( 'gridwp-focus' );
                }
            };

            for ( gridwp_primary_i = 0; gridwp_primary_i < parentLink.length; ++gridwp_primary_i ) {
                parentLink[gridwp_primary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( gridwp_primary_container ) );
} )();